/*
 * componentconfigurator.cpp
 * Copyright 2005 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *     Steve Grubb <sgrubb@redhat.com>
 */
#include "componentconfigurator.h"
#include "application.h"

/**
 * Constructors/Destructors
 */
ComponentConfigurator *ComponentConfigurator::_instance = 0;
/**
 * Methods
 */
/**
 * Get the value of repo
 * This class owns the Component Repository.
 * @return the value of repo
 */
ComponentRepository ComponentConfigurator::get_repo ( ) {
	return repo;
}
/**
 * Set the value of repo
 * This class owns the Component Repository.
 * @param value the value of repo
 */
void ComponentConfigurator::set_repo (ComponentRepository value ) {
	
}
/**
 * Get the value of config_file
 * This is the location where the config file resides.
 * @return the value of config_file
 */
const char * ComponentConfigurator::get_config_file ( ) {
	return config_file;
}
/**
 * Set the value of config_file
 * This is the location where the config file resides.
 * @param value the value of config_file
 */
void ComponentConfigurator::set_config_file (const char * value ) {
	
}
/**
 * This method causes the class to read the config file located by the
 * config_file attribute.
 */
int ComponentConfigurator::read_config () {
	return 0;
}
/**
 * This method will start the init process for the whole program. It
 * should only be invoked once.
 */
int ComponentConfigurator::init () {
	int rc;

	// create repo
	rc = read_config();
	if (rc)
		return rc;

	// Create the application component. This will be needed no
	// matter what the config says.
	Application *app = Application::instance();
	app->init("dummy config string");
	repo.insert((Component &)*app);

	// FIXME: create components based on config

    return 0;
}
/**
 * This method tells the configurator to read the config file and
 * reconfigure all components without taking down the application.
 */
void ComponentConfigurator::reconfigure () {
	
}
/**
 * This method is called to stop all processing before terminating
 * the application or reconfiguring the plugins.
 */
void ComponentConfigurator::suspend_all () {
	
}

