/*
 * fault.h
 * Copyright 2005 Linuon Inc. Tokyo Japan All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *     Junji Kanemaru <junji.kanemaru@linuon.com>
 */
#ifndef FAULT_H
#define FAULT_H
#include <errno.h>
#include <string.h>
#include <string>

/**
** Fault class will be thrown when error occurred. If real fatal like
** NULL pointer or something like that then use assert() instead. */
class Fault {
public:
    typedef enum {
        SYSTEM,
        APPLICATION,
        USER
    } Kind;

    Fault(Kind kind, 
          int code, 
          const std::string& msg, 
          const char* file, 
          const int line);

    ~Fault();

    int kind();
    int code();
    std::string message();
    std::string file();
    int line();

protected:

private:
    int _kind;
    int _code;
    char* _file;
    int _line;
    std::string _msg;
};

/**
** Constractors/Destrator */
inline Fault::Fault(Kind kind,
                    int code, 
                    const std::string& msg,
                    const char* file, 
                    const int line) {
    _kind = kind;
    _code = code;
    _line = line;
    _file = strdup(file);
    _msg = msg;
}

inline Fault::~Fault() {
    if (_file) {
        free(_file);
    }
}

/**
** Public inline methods */
inline int Fault::code() {
    return _code;
}

inline std::string Fault::file() {
    return _file;
}

inline int Fault::line() {
    return _line;
}

/* Fancy macros */
#define SYSTEM_FAULT(e, m) \
    Fault(Fault::SYSTEM, ((int)e), (m), __FILE__, __LINE__)
#define APP_FAULT(e, m) \
    Fault(Fault::APPLICATION, ((int)e), (m), __FILE__, __LINE__)
#define USER_FAULT(e, m) \
    Fault(Fault::USER, ((int)e), (m), __FILE__, __LINE__)

#endif /* FAULT_H */
